diff --git a/crypto-cipher-types.cabal b/crypto-cipher-types.cabal
--- a/crypto-cipher-types.cabal
+++ b/crypto-cipher-types.cabal
@@ -1,5 +1,5 @@
 Name:                crypto-cipher-types
-Version:             0.0.4
+Version:             0.0.5
 Synopsis:            Generic cryptography cipher types
 Description:         Generic cryptography cipher types
 License:             BSD3

diff --git a/Crypto/Cipher/Types.hs b/Crypto/Cipher/Types.hs
--- a/Crypto/Cipher/Types.hs
+++ b/Crypto/Cipher/Types.hs
@@ -79,10 +79,8 @@
 
 -- | Symmetric stream cipher class
 class Cipher cipher => StreamCipher cipher where
-    -- | Encrypt using the stream cipher
-    streamEncrypt :: cipher -> ByteString -> (ByteString, cipher)
-    -- | Decrypt using the stream cipher
-    streamDecrypt :: cipher -> ByteString -> (ByteString, cipher)
+    -- | Combine using the stream cipher
+    streamCombine :: cipher -> ByteString -> (ByteString, cipher)
 
 -- | Symmetric block cipher class
 class Cipher cipher => BlockCipher cipher where